'''Static geometry
'''

import pyglet
from pyglet.gl import *
import pymunk
import random

class Rock(object):
    def __init__(self, space, x = 0, y = 0, radius = 100,
                 imgfile = 'roundrock.png'):
        self.body = pymunk.Body(pymunk.inf, pymunk.inf)
        self.body.position.x = x
        self.body.position.y = y
        self.shape = pymunk.Circle(self.body, radius, (0,0))
        space.add_static(self.shape)
        img = pyglet.resource.image(imgfile)
        img.anchor_x = img.width // 2
        img.anchor_y = img.height // 2
        self.sprite = pyglet.sprite.Sprite(img, x = x, y = y)
        self.sprite.rotation = random.randint(0,359)

    def draw(self):
        self.sprite.draw()


class Wall(object):
    def __init__(self, space, x1, y1, x2, y2):
        radius = 100
        self.x1 = x1
        self.y1 = y1
        self.x2 = x2
        self.y2 = y2
        self.body = pymunk.Body(pymunk.inf, pymunk.inf)
        self.shape = pymunk.Poly(self.body,
                                 [(x1, y1), (x1, y2), (x2, y2), (x2, y1)],
                                 (0,0))
        space.add(self.shape)
        img = pyglet.resource.image('brick_tex.png')
        self.texture = img.get_texture()
        self.tex_scale_width = (x2 - x1) / float(img.width)
        self.tex_scale_height = (y2 - y1) / float(img.height)

    def draw(self):
        glColor3f(1.0, 1.0, 1.0)
        glEnable(GL_TEXTURE_2D)
        glBindTexture(self.texture.target, self.texture.id)
        glBegin(GL_QUADS)
        glTexCoord2f(self.texture.tex_coords[0] * self.tex_scale_width,
                     self.texture.tex_coords[1] * self.tex_scale_height)
        glVertex2f(self.x1, self.y1)
        glTexCoord2f(self.texture.tex_coords[3] * self.tex_scale_width,
                     self.texture.tex_coords[4] * self.tex_scale_height)
        glVertex2f(self.x2, self.y1)
        glTexCoord2f(self.texture.tex_coords[6] * self.tex_scale_width,
                     self.texture.tex_coords[7] * self.tex_scale_height)
        glVertex2f(self.x2, self.y2)
        glTexCoord2f(self.texture.tex_coords[9] * self.tex_scale_width,
                     self.texture.tex_coords[10] * self.tex_scale_height)
        glVertex2f(self.x1, self.y2)
        glEnd()
        
